==> smartgwt-6.1p.zip: com/smartgwt/logicalstructure/widgets/CanvasLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class CanvasLogicalStructure extends BaseWidgetLogicalStructure {
    public String accessKey;
    public String adaptiveHeightPriority;
    public String adaptiveWidthPriority;
    public String alwaysShowScrollbars;
    public String animateAcceleration;
    public String animateFadeTime;
    public String animateHideAcceleration;
    public String animateHideTime;
    public String animateMoveAcceleration;
    public String animateMoveTime;
    public String animateRectAcceleration;
    public String animateRectTime;
    public String animateResizeAcceleration;
    public String animateResizeTime;
    public String animateScrollAcceleration;
    public String animateScrollTime;
    public String animateShowAcceleration;
    public String animateShowTime;
    public String animateTime;
    public String appImgDir;
    public String ariaRole;
    public String autoDraw;
    public String autoMaskComponents;
    public String autoParent;
    public String autoShowParent;
    public String backgroundColor;
    public String backgroundImage;
    public String backgroundPosition;
    public String backgroundRepeat;
    public String border;
    public String canAcceptDrop;
    public String canAdaptHeight;
    public String canAdaptWidth;
    public String canDrag;
    public String canDragReposition;
    public String canDragResize;
    public String canDragScroll;
    public String canDrop;
    public String canDropBefore;
    public String canFocus;
    public String canHover;
    public String canSelectText;
    public CanvasItem canvasItem;
    public Canvas[] children;
    public String childrenResizeSnapAlign;
    public String childrenSnapAlign;
    public String childrenSnapCenterAlign;
    public String childrenSnapEdgeAlign;
    public String childrenSnapResizeToGrid;
    public String childrenSnapToGrid;
    public String contents;
    public Menu contextMenu;
    public String correctZoomOverflow;
    public String cursor;
    public String dataPath;
    public String defaultHeight;
    public String defaultWidth;
    public String destroyed;
    public String destroying;
    public String disabled;
    public String disabledCursor;
    public String disableTouchScrollingForDrag;
    public String doubleClickDelay;
    public String dragAppearance;
    public String dragIntersectStyle;
    public String dragMaskType;
    public String dragMaxHeight;
    public String dragMaxWidth;
    public String dragMinHeight;
    public String dragMinWidth;
    public String dragOpacity;
    public String dragRepositionAppearance;
    public String dragRepositionCursor;
    public String dragResizeAppearance;
    public String dragScrollDelay;
    public String dragStartDistance;
    public Canvas dragTargetAsCanvas;
    public String dragTargetAsString;
    public String dragType;
    public String[] dropTypesAsStringArrayArray;
    public String dynamicContents;
    public String edgeBackgroundColor;
    public String edgeCenterBackgroundColor;
    public String edgeImage;
    public String edgeMarginSize;
    public String edgeOffset;
    public String edgeOpacity;
    public String edgeShowCenter;
    public String edgeSize;
    public EditNode editNode;
    public String editProxyConstructor;
    public AdvancedCriteria enableWhen;
    public String endLine;
    public String extraSpace;
    public String groupBorderCSS;
    public String groupLabelBackgroundColor;
    public String groupLabelStyleName;
    public String groupTitle;
    public String hideUsingDisplayNone;
    public String hoverAlign;
    public String hoverAutoDestroy;
    public String hoverAutoFitMaxWidthAsString;
    public String hoverAutoFitWidth;
    public String hoverDelay;
    public String hoverHeight;
    public String hoverMoveWithMouse;
    public String hoverOpacity;
    public String hoverStyle;
    public String hoverVAlign;
    public String hoverWidth;
    public String hoverWrap;
    public String htmlElement;
    public String htmlPosition;
    public String ID;
    public String isGroup;
    public String isPrinting;
    public String isRuleScope;
    public String isSnapAlignCandidate;
    public String leavePageSpace;
    public String locateChildrenBy;
    public String locateChildrenType;
    public String locatePeersBy;
    public String locatePeersType;
    public String margin;
    public Canvas masterElement;
    public String matchElement;
    public String maxHeight;
    public String maxWidth;
    public String maxZoomOverflowError;
    public String menuConstructor;
    public String minNonEdgeSize;
    public String momentumScrollMinSpeed;
    public String mouseStillDownDelay;
    public String mouseStillDownInitialDelay;
    public String noDoubleClicks;
    public String noDropCursor;
    public String opacity;
    public String overflow;
    public String padding;
    public Canvas parentCanvas;
    public Canvas parentElement;
    public Canvas[] peers;
    public String percentBox;
    public Canvas percentSource;
    public String position;
    public String printChildrenAbsolutelyPositioned;
    public String prompt;
    public String[] proportionalResizeModifiers;
    public String proportionalResizing;
    public String redrawOnResize;
    public String resizeBarTarget;
    public String[] resizeFrom;
    public String ruleScope;
    public String scrollbarSize;
    public String shadowColor;
    public String shadowDepth;
    public String shadowHOffset;
    public String shadowImage;
    public String shadowOffset;
    public String shadowSoftness;
    public String shadowSpread;
    public String shadowVOffset;
    public String shouldPrint;
    public String showCustomScrollbars;
    public String showDragShadow;
    public String showEdges;
    public String showHover;
    public String showHoverComponents;
    public String showResizeBar;
    public String showShadow;
    public String showSnapGrid;
    public String shrinkElementOnHide;
    public String sizeMayChangeOnRedraw;
    public String skinImgDir;
    public Canvas[] snapAlignCandidates;
    public String snapAlignCenterLineStyle;
    public String snapAlignEdgeLineStyle;
    public String snapAxis;
    public String snapEdge;
    public String snapHDirection;
    public String snapHGap;
    public String snapOffsetLeft;
    public String snapOffsetTop;
    public String snapOnDrop;
    public String snapResizeToAlign;
    public String snapResizeToGrid;
    public String snapTo;
    public String snapToAlign;
    public String snapToCenterAlign;
    public String snapToEdgeAlign;
    public String snapToGrid;
    public String snapVDirection;
    public String snapVGap;
    public String startLine;
    public String styleName;
    public String tabIndex;
    public Canvas topElement;
    public String updateTabPositionOnDraw;
    public String updateTabPositionOnReparent;
    public String useBackMask;
    public String useCSSShadow;
    public String useImageForSVG;
    public String useNativeDrag;
    public String useOpacityFilter;
    public String useTouchScrolling;
    public ValuesManager valuesManagerAsValuesManager;
    public String valuesManagerAsString;
    public String visibility;
    public AdvancedCriteria visibleWhen;
}

==> smartgwt-14.0p.zip: com/smartgwt/logicalstructure/widgets/CanvasLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.util.tour.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class CanvasLogicalStructure extends BaseWidgetLogicalStructure {
    public String accessKey;
    public String adaptiveHeightPriority;
    public String adaptiveWidthPriority;
    public String alwaysManageFocusNavigation;
    public String alwaysShowScrollbars;
    public String animateAcceleration;
    public String animateFadeTime;
    public String animateHideAcceleration;
    public String animateHideTime;
    public String animateMoveAcceleration;
    public String animateMoveTime;
    public String animateRectAcceleration;
    public String animateRectTime;
    public String animateResizeAcceleration;
    public String animateResizeLayoutMode;
    public String animateResizeTime;
    public String animateScrollAcceleration;
    public String animateScrollTime;
    public String animateShowAcceleration;
    public String animateShowTime;
    public String animateTime;
    public String appImgDir;
    public String ariaRole;
    public String autoMaskComponents;
    public String autoParent;
    public String autoPopulateData;
    public String autoShowParent;
    public String backgroundColor;
    public String backgroundImage;
    public String backgroundPosition;
    public String backgroundRepeat;
    public String border;
    public String borderRadius;
    public String canAcceptDrop;
    public String canAdaptHeight;
    public String canAdaptWidth;
    public String canDrag;
    public String canDragReposition;
    public String canDragResize;
    public String canDragScroll;
    public String canDrop;
    public String canDropBefore;
    public String canFocus;
    public String canHover;
    public String canSelectText;
    public CanvasItem canvasItem;
    public Canvas[] children;
    public String childrenResizeSnapAlign;
    public String childrenSnapAlign;
    public String childrenSnapCenterAlign;
    public String childrenSnapEdgeAlign;
    public String childrenSnapResizeToGrid;
    public String childrenSnapToGrid;
    public String contents;
    public Menu contextMenu;
    public String correctZoomOverflow;
    public String cursor;
    public DataContext dataContext;
    public String dataPath;
    public String defaultHeight;
    public String defaultWidth;
    public String definingProperty;
    public String[] definingPropertyNameOptions;
    public String destroyed;
    public String destroying;
    public String disabled;
    public String disabledCursor;
    public String disableTouchScrollingForDrag;
    public String doubleClickDelay;
    public String dragAppearance;
    public String dragIntersectStyle;
    public String dragMaskType;
    public String dragMaxHeight;
    public String dragMaxWidth;
    public String dragMinHeight;
    public String dragMinWidth;
    public String dragOpacity;
    public String dragRepositionAppearance;
    public String dragRepositionCursor;
    public String dragResizeAppearance;
    public String dragScrollDelay;
    public String dragStartDistance;
    public Canvas dragTargetAsCanvas;
    public String dragTargetAsString;
    public String dragType;
    public Canvas dropTargetAsCanvas;
    public String dropTargetAsString;
    public String[] dropTypesAsStringArrayArray;
    public String dynamicContents;
    public String edgeBackgroundColor;
    public String edgeCenterBackgroundColor;
    public String edgeImage;
    public String edgeMarginSize;
    public String edgeOffset;
    public String edgeOpacity;
    public String edgeShowCenter;
    public String edgeSize;
    public EditNode editNode;
    public String editProxyConstructor;
    public AdvancedCriteria enableWhen;
    public String endLine;
    public String extraSpace;
    public String floatingScrollbars;
    public String forwardSVGeventsToObject;
    public String groupBorderCSS;
    public String groupLabelBackgroundColor;
    public String groupLabelStyleName;
    public String groupPadding;
    public String groupTitle;
    public String hideUsingDisplayNone;
    public String hoverAlign;
    public String hoverAutoDestroy;
    public String hoverAutoFitMaxWidthAsString;
    public String hoverAutoFitWidth;
    public String hoverDelay;
    public String hoverFocusKey;
    public String hoverHeight;
    public String hoverMoveWithMouse;
    public String hoverOpacity;
    public String hoverPersist;
    public String hoverScreen;
    public String hoverStyle;
    public String hoverVAlign;
    public String hoverWidth;
    public String hoverWrap;
    public String htmlElementAsString;
    public String htmlPosition;
    public String ID;
    public String isGroup;
    public String isPrinting;
    public String isRuleScope;
    public String isSnapAlignCandidate;
    public String leaveGroupLabelSpace;
    public String leavePageSpace;
    public String locateByIDOnly;
    public String locateChildrenBy;
    public String locateChildrenType;
    public String locatePeersBy;
    public String locatePeersType;
    public String locatorName;
    public String margin;
    public Canvas masterElement;
    public String matchElement;
    public String matchElementHeight;
    public String matchElementWidth;
    public String maxHeight;
    public String maxWidth;
    public String maxZoomOverflowError;
    public String menuConstructor;
    public String minNonEdgeSize;
    public String momentumScrollMinSpeed;
    public String mouseStillDownDelay;
    public String mouseStillDownInitialDelay;
    public String name;
    public String nativeAutoHideScrollbars;
    public String noDoubleClicks;
    public String noDropCursor;
    public String opacity;
    public String overflow;
    public String padding;
    public Canvas parentCanvas;
    public Canvas parentElement;
    public Canvas[] peers;
    public String pendingMarkerStyle;
    public String pendingMarkerVisible;
    public String percentBox;
    public Canvas percentSource;
    public String persistentMatchElement;
    public PointerSettings pointerSettings;
    public String position;
    public String printChildrenAbsolutelyPositioned;
    public String printStyleName;
    public String prompt;
    public String[] proportionalResizeModifiers;
    public String proportionalResizing;
    public String receiveScrollbarEvents;
    public String redrawOnResize;
    public String resizeBarTarget;
    public String[] resizeFrom;
    public String ruleScope;
    public String scrollbarSize;
    public String shadowColor;
    public String shadowDepth;
    public String shadowHOffset;
    public String shadowImage;
    public String shadowOffset;
    public String shadowSoftness;
    public String shadowSpread;
    public String shadowVOffset;
    public String shouldPrint;
    public String showCustomScrollbars;
    public String showDragShadow;
    public String showEdges;
    public String showHover;
    public String showHoverComponents;
    public String showPointer;
    public String showResizeBar;
    public String showShadow;
    public String showSnapGrid;
    public String shrinkElementOnHide;
    public String sizeMayChangeOnRedraw;
    public String skinImgDir;
    public Canvas[] snapAlignCandidates;
    public String snapAlignCenterLineStyle;
    public String snapAlignEdgeLineStyle;
    public String snapAxis;
    public String snapEdge;
    public String snapGridStyle;
    public String snapHDirection;
    public String snapHGap;
    public String snapOffsetLeft;
    public String snapOffsetTop;
    public String snapOnDrop;
    public String snapResizeToAlign;
    public String snapResizeToGrid;
    public String snapTo;
    public String snapToAlign;
    public String snapToCenterAlign;
    public String snapToEdgeAlign;
    public String snapToGrid;
    public String snapVDirection;
    public String snapVGap;
    public String startLine;
    public String styleName;
    public String tabIndex;
    public DataContext testDataContext;
    public Canvas topElement;
    public String updateTabPositionOnDraw;
    public String updateTabPositionOnReparent;
    public String useBackMask;
    public String useCSSShadow;
    public String useImageForSVG;
    public String useNativeDrag;
    public String useOpacityFilter;
    public String useTouchScrolling;
    public ValuesManager valuesManagerAsValuesManager;
    public String valuesManagerAsString;
    public String visibility;
    public AdvancedCriteria visibleWhen;
    public Process[] workflows;
}
